// Copyright 2006 Nokia Corporation.
//
// THIS SOURCE CODE IS PROVIDED 'AS IS', WITH NO WARRANTIES WHATSOEVER,
// EXPRESS OR IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY, FITNESS
// FOR ANY PARTICULAR PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE
// OR TRADE PRACTICE, RELATING TO THE SOURCE CODE OR ANY WARRANTY OTHERWISE
// ARISING OUT OF ANY PROPOSAL, SPECIFICATION, OR SAMPLE AND WITH NO
// OBLIGATION OF NOKIA TO PROVIDE THE LICENSEE WITH ANY MAINTENANCE OR
// SUPPORT. FURTHERMORE, NOKIA MAKES NO WARRANTY THAT EXERCISE OF THE
// RIGHTS GRANTED HEREUNDER DOES NOT INFRINGE OR MAY NOT CAUSE INFRINGEMENT
// OF ANY PATENT OR OTHER INTELLECTUAL PROPERTY RIGHTS OWNED OR CONTROLLED
// BY THIRD PARTIES
//
// Furthermore, information provided in this source code is preliminary,
// and may be changed substantially prior to final release. Nokia Corporation
// retains the right to make changes to this source code at
// any time, without notice. This source code is provided for informational
// purposes only.
//
// Nokia and Nokia Connecting People are registered trademarks of Nokia
// Corporation.
// Java and all Java-based marks are trademarks or registered trademarks of
// Sun Microsystems, Inc.
// Other product and company names mentioned herein may be trademarks or
// trade names of their respective owners.
//
// A non-exclusive, non-transferable, worldwide, limited license is hereby
// granted to the Licensee to download, print, reproduce and modify the
// source code. The licensee has the right to market, sell, distribute and
// make available the source code in original or modified form only when
// incorporated into the programs developed by the Licensee. No other
// license, express or implied, by estoppel or otherwise, to any other
// intellectual property rights is granted herein.
package bcexchanger.ui;

import javax.microedition.lcdui.Alert;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.Displayable;
import bcexchanger.*;

/**
 * 
 * This class represents a screen displaying an alert message. The
 * class is extending an example.BCExchanger.ui.Screen class
 * 
 * @version 1.0 20.09.2005
 * @see example.BCExchanger.ui.Screen Design patterns: State
 */
public class AlertMessage extends Screen {

  Alert alert;
  Screen nextScreen = null;
  boolean quitAfterDismiss = false;

  /**
   * Constructor
   * 
   * @param _midlet -
   *          the parent class which keeps the current UI state
   * @param message -
   *          text to display
   * @param _nextScreen -
   *          UI screen should be displayed after the alarm message is
   *          dismissed
   */
  public AlertMessage(BCExchangerMIDlet _midlet, String message,
      Screen _nextScreen) {
    super(_midlet);

    nextScreen = _nextScreen;
    init(message);
  }

  /**
   * Constructor
   * 
   * If this constructor is used, the application will exit after the
   * alert is dismissed
   * 
   * @param _midlet -
   *          the parent class which keeps the current UI state
   * @param message -
   *          text to display
   */
  public AlertMessage(BCExchangerMIDlet _midlet, String message) {
    super(_midlet);

    //quitAfterDismiss = true;
    init(message);
  }

  /**
   * Initialise the displayable
   * 
   * @param message -
   *          text to display
   */
  private void init(String message) {

    alert = new Alert("", message, null, null);
    alert.setCommandListener(this);

    displayable = alert;
  }

  public void commandAction(Command command, Displayable _displayable) {
    if (_displayable != alert) {
      // wrong displayable
      throw new RuntimeException("Internal error #28");
    }

    if (command == Alert.DISMISS_COMMAND) {
      if (quitAfterDismiss) {
        midlet.quit();
      } else {
        if (nextScreen != null) {
          midlet.changeScreen(nextScreen);
        }
      }
    } else {
      // unknown command
      throw new RuntimeException("Internal error #29");
    }
  }

}
